deepint.error
=================

.. automodule:: deepint.error
   :special-members:
   :exclude-members:
   :members:

.. autoclass:: deepint.error.DeepintBaseError
   :exclude-members:
   :members:

.. autoclass:: deepint.error.DeepintHTTPError
   :exclude-members:
   :members:

.. autoclass:: deepint.error.DeepintCredentialsError
   :exclude-members:
   :members:

.. autoclass:: deepint.error.DeepintTaskError
   :exclude-members:
   :members: